@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2021 Memgraph Ltd. [https://memgraph.com]
+# Copyright (c) 2016-2022 Memgraph Ltd. [https://memgraph.com]
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -111,7 +111,6 @@ def _convert_memgraph_value(value: Any) -> Any:
             {
                 "_type": value.type,
                 "_id": value.id,
-                "_relationship_type": value.type,
                 "_start_node_id": value.start_id,
                 "_end_node_id": value.end_id,
                 **value.properties,
@@ -121,9 +120,8 @@ def _convert_memgraph_value(value: Any) -> Any:
     if isinstance(value, mgclient.Node):
         return Node.parse_obj(
             {
-                "_type": "".join(value.labels),
                 "_id": value.id,
-                "_node_labels": set(value.labels),
+                "_labels": set(value.labels),
                 **value.properties,
             }
         )
